/*************************************************************************************
 Copyright (c) 2006. Centre for e-Science. Lancaster University. United Kingdom.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 *************************************************************************************/

package uk.ac.lancs.e_science.sakaiproject.api.blogger.post.reader;

import uk.ac.lancs.e_science.sakaiproject.api.blogger.post.*;

public interface PostConverter {
    public void reset();
    public void convertOID(String oid);
    public void convertTitle(String title);
    public void convertShortText(String title);
    public void convertDatePost(long date);
    public void convertCreator(Creator creator);
    public void convertState(State state);
    public void convertKeywords(String[] keywords);
    public void convertLinkRules(LinkRule linkRules);
    public void convertImage(Image image);
    public void convertFile(File file);
    public void convertParagraph(Paragraph paragraph);
    public void convertComments(Comment[] comments);
}
